Class: Google::Cloud::Lustre::V1::CreateInstanceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Lustre::V1::CreateInstanceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/lustre/v1/instance.rb
Overview
Message for creating a Instance
Instance Attribute Summary collapse
-
#instance ⇒ ::Google::Cloud::Lustre::V1::Instance
Required.
-
#instance_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#instance ⇒ ::Google::Cloud::Lustre::V1::Instance
Returns Required. The resource being created.
195 196 197 198 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 195 class CreateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_id ⇒ ::String
Returns Required. The name of the Managed Lustre instance.
- Must contain only lowercase letters, numbers, and hyphens.
- Must start with a letter.
- Must be between 1-63 characters.
- Must end with a number or a letter.
195 196 197 198 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 195 class CreateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The instance's project and location, in the format
projects/{project}/locations/{location}. Locations map to Google Cloud
zones; for example, us-west1-b.
195 196 197 198 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 195 class CreateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
195 196 197 198 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 195 class CreateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |