Class: Google::Cloud::Lustre::V1::ErrorLogEntry
- Inherits:
-
Object
- Object
- Google::Cloud::Lustre::V1::ErrorLogEntry
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/lustre/v1/transfer.rb
Overview
An entry describing an error that has occurred.
Instance Attribute Summary collapse
-
#error_details ⇒ ::Array<::String>
A list of messages that carry the error details.
-
#uri ⇒ ::String
Required.
Instance Attribute Details
#error_details ⇒ ::Array<::String>
Returns A list of messages that carry the error details.
223 224 225 226 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 223 class ErrorLogEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#uri ⇒ ::String
Returns Required. A URL that refers to the target (a data source, a data sink, or an object) with which the error is associated.
223 224 225 226 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 223 class ErrorLogEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |