Class: Google::Cloud::Lustre::V1::ErrorSummary
- Inherits:
-
Object
- Object
- Google::Cloud::Lustre::V1::ErrorSummary
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/lustre/v1/transfer.rb
Overview
A summary of errors by error code, plus a count and sample error log entries.
Instance Attribute Summary collapse
-
#error_code ⇒ ::Google::Rpc::Code
Required.
-
#error_count ⇒ ::Integer
Required.
-
#error_log_entries ⇒ ::Array<::Google::Cloud::Lustre::V1::ErrorLogEntry>
Error samples.
Instance Attribute Details
#error_code ⇒ ::Google::Rpc::Code
Returns Required.
242 243 244 245 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 242 class ErrorSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error_count ⇒ ::Integer
Returns Required. Count of this type of error.
242 243 244 245 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 242 class ErrorSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error_log_entries ⇒ ::Array<::Google::Cloud::Lustre::V1::ErrorLogEntry>
Returns Error samples.
At most 5 error log entries are recorded for a given error code for a single transfer operation.
242 243 244 245 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 242 class ErrorSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |