Class: Google::Cloud::Lustre::V1::ImportDataRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/lustre/v1/transfer.rb

Overview

Message for importing data to Lustre.

Instance Attribute Summary collapse

Instance Attribute Details

#gcs_path::Google::Cloud::Lustre::V1::GcsPath

Returns The Cloud Storage source bucket and, optionally, path inside the bucket. If a path inside the bucket is specified, it must end with a forward slash (/).

Returns:

  • (::Google::Cloud::Lustre::V1::GcsPath)

    The Cloud Storage source bucket and, optionally, path inside the bucket. If a path inside the bucket is specified, it must end with a forward slash (/).



44
45
46
47
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 44

class ImportDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#lustre_path::Google::Cloud::Lustre::V1::LustrePath

Returns Lustre path destination.

Returns:



44
45
46
47
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 44

class ImportDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the Managed Lustre instance in the format projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The name of the Managed Lustre instance in the format projects/{project}/locations/{location}/instances/{instance}.



44
45
46
47
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 44

class ImportDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. UUID to identify requests.

Returns:

  • (::String)

    Optional. UUID to identify requests.



44
45
46
47
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 44

class ImportDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_account::String

Returns Optional. User-specified service account used to perform the transfer. If unspecified, the default Managed Lustre service agent will be used.

Returns:

  • (::String)

    Optional. User-specified service account used to perform the transfer. If unspecified, the default Managed Lustre service agent will be used.



44
45
46
47
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 44

class ImportDataRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end