Class: Google::Cloud::Lustre::V1::ListInstancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/lustre/v1/instance.rb

Overview

Message for requesting list of Instances

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filtering results.

Returns:

  • (::String)

    Optional. Filtering results.



133
134
135
136
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 133

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Desired order of results.

Returns:

  • (::String)

    Optional. Desired order of results.



133
134
135
136
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 133

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server might return fewer items than requested. If unspecified, the server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server might return fewer items than requested. If unspecified, the server will pick an appropriate default.



133
134
135
136
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 133

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



133
134
135
136
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 133

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The project and location for which to retrieve a list of instances, in the format projects/{projectId}/locations/{location}.

To retrieve instance information for all locations, use "-" as the value of {location}.

Returns:

  • (::String)

    Required. The project and location for which to retrieve a list of instances, in the format projects/{projectId}/locations/{location}.

    To retrieve instance information for all locations, use "-" as the value of {location}.



133
134
135
136
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 133

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end