Class: Google::Cloud::Lustre::V1::ListInstancesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/lustre/v1/instance.rb

Overview

Message for response to listing Instances

Instance Attribute Summary collapse

Instance Attribute Details

#instances::Array<::Google::Cloud::Lustre::V1::Instance>

Returns Response from ListInstances.

Returns:



148
149
150
151
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 148

class ListInstancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token identifying a page of results the server should return.

Returns:

  • (::String)

    A token identifying a page of results the server should return.



148
149
150
151
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 148

class ListInstancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unordered list. Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Unordered list. Locations that could not be reached.



148
149
150
151
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 148

class ListInstancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end