Class: Google::Cloud::Lustre::V1::ExportDataRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Lustre::V1::ExportDataRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/lustre/v1/transfer.rb
Overview
Export data from Managed Lustre to a Cloud Storage bucket.
Instance Attribute Summary collapse
-
#gcs_path ⇒ ::Google::Cloud::Lustre::V1::GcsPath
The URI to a Cloud Storage bucket, or a path within a bucket, using the format
gs://<bucket_name>/<optional_path_inside_bucket>/. -
#lustre_path ⇒ ::Google::Cloud::Lustre::V1::LustrePath
The root directory path to the Managed Lustre file system.
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
-
#service_account ⇒ ::String
Optional.
Instance Attribute Details
#gcs_path ⇒ ::Google::Cloud::Lustre::V1::GcsPath
Returns The URI to a Cloud Storage bucket, or a path within a bucket, using
the format gs://<bucket_name>/<optional_path_inside_bucket>/. If a
path inside the bucket is specified, it must end with a forward slash
(/).
71 72 73 74 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 71 class ExportDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#lustre_path ⇒ ::Google::Cloud::Lustre::V1::LustrePath
Returns The root directory path to the Managed Lustre file system. Must start
with /. Default is /.
71 72 73 74 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 71 class ExportDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the Managed Lustre instance in the format
projects/{project}/locations/{location}/instances/{instance}.
71 72 73 74 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 71 class ExportDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. UUID to identify requests.
71 72 73 74 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 71 class ExportDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_account ⇒ ::String
Returns Optional. User-specified service account used to perform the transfer. If unspecified, the Managed Lustre service agent is used.
71 72 73 74 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 71 class ExportDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |