Class: Google::Cloud::Lustre::V1::GcsPath
- Inherits:
-
Object
- Object
- Google::Cloud::Lustre::V1::GcsPath
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/lustre/v1/transfer.rb
Overview
Specifies a Cloud Storage bucket and, optionally, a path inside the bucket.
Instance Attribute Summary collapse
-
#uri ⇒ ::String
Required.
Instance Attribute Details
#uri ⇒ ::String
Returns Required. The URI to a Cloud Storage bucket, or a path within a bucket,
using the format gs://<bucket_name>/<optional_path_inside_bucket>/. If a
path inside the bucket is specified, it must end with a forward slash
(/).
162 163 164 165 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 162 class GcsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |