Class: Google::Cloud::Lustre::V1::Instance
- Inherits:
-
Object
- Object
- Google::Cloud::Lustre::V1::Instance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/lustre/v1/instance.rb
Overview
A Managed Lustre instance.
Defined Under Namespace
Modules: State Classes: LabelsEntry
Instance Attribute Summary collapse
-
#capacity_gib ⇒ ::Integer
Required.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#filesystem ⇒ ::String
Required.
-
#gke_support_enabled ⇒ ::Boolean
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#mount_point ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#network ⇒ ::String
Required.
-
#per_unit_storage_throughput ⇒ ::Integer
Required.
-
#state ⇒ ::Google::Cloud::Lustre::V1::Instance::State
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#capacity_gib ⇒ ::Integer
Returns Required. The storage capacity of the instance in gibibytes (GiB). Allowed
values are from 18000 to 954000, in increments of 9000.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the instance was created.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#description ⇒ ::String
Returns Optional. A user-readable description of the instance.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#filesystem ⇒ ::String
Returns Required. Immutable. The filesystem name for this instance. This name is used by client-side tools, including when mounting the instance. Must be eight characters or less and can only contain letters and numbers.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#gke_support_enabled ⇒ ::Boolean
This field is deprecated and may be removed in the next major version update.
Returns Optional. Indicates whether you want to enable support for GKE clients. By default, GKE clients are not supported. Deprecated. No longer required for GKE instance creation.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#mount_point ⇒ ::String (readonly)
Returns Output only. Mount point of the instance in the format
IP_ADDRESS@tcp:/FILESYSTEM.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#name ⇒ ::String
Returns Identifier. The name of the instance.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#network ⇒ ::String
Returns Required. Immutable. The full name of the VPC network to which the instance
is connected. Must be in the format
projects/{project_id}/global/networks/{network_name}.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#per_unit_storage_throughput ⇒ ::Integer
Returns Required. The throughput of the instance in MB/s/TiB. Valid values are 125, 250, 500, 1000.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#state ⇒ ::Google::Cloud::Lustre::V1::Instance::State (readonly)
Returns Output only. The state of the instance.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the instance was last updated.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/lustre/v1/instance.rb', line 71 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an instance. module State # Not set. STATE_UNSPECIFIED = 0 # The instance is available for use. ACTIVE = 1 # The instance is being created and is not yet ready for use. CREATING = 2 # The instance is being deleted. DELETING = 3 # The instance is being upgraded. UPGRADING = 4 # The instance is being repaired. REPAIRING = 5 # The instance is stopped. STOPPED = 6 # The instance is being updated. UPDATING = 7 end end |