Class: Google::Cloud::Lustre::V1::LustrePath
- Inherits:
-
Object
- Object
- Google::Cloud::Lustre::V1::LustrePath
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/lustre/v1/transfer.rb
Overview
The root directory path to the Lustre file system.
Instance Attribute Summary collapse
-
#path ⇒ ::String
Optional.
Instance Attribute Details
#path ⇒ ::String
Returns Optional. The root directory path to the Managed Lustre file system. Must
start with
/. Default is /. If you're importing data into Managed Lustre, any
path other than the default must already exist on the file system.
174 175 176 177 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 174 class LustrePath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |