Class: Google::Cloud::Lustre::V1::TransferCounters
- Inherits:
-
Object
- Object
- Google::Cloud::Lustre::V1::TransferCounters
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/lustre/v1/transfer.rb
Overview
A collection of counters that report the progress of a transfer operation.
Instance Attribute Summary collapse
-
#bytes_copied_count ⇒ ::Integer
Bytes that are copied to the data destination.
-
#bytes_failed_count ⇒ ::Integer
readonly
Output only.
-
#bytes_found_count ⇒ ::Integer
Total number of bytes found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync.
-
#bytes_skipped_count ⇒ ::Integer
Bytes in the data source that are not transferred because they already exist in the data destination.
-
#found_objects_count ⇒ ::Integer
Objects found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync.
-
#objects_copied_count ⇒ ::Integer
Objects that are copied to the data destination.
-
#objects_failed_count ⇒ ::Integer
readonly
Output only.
-
#objects_skipped_count ⇒ ::Integer
Objects in the data source that are not transferred because they already exist in the data destination.
Instance Attribute Details
#bytes_copied_count ⇒ ::Integer
Returns Bytes that are copied to the data destination.
210 211 212 213 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 210 class TransferCounters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bytes_failed_count ⇒ ::Integer (readonly)
Returns Output only. Bytes that are failed to write to the data destination.
210 211 212 213 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 210 class TransferCounters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bytes_found_count ⇒ ::Integer
Returns Total number of bytes found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync.
210 211 212 213 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 210 class TransferCounters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bytes_skipped_count ⇒ ::Integer
Returns Bytes in the data source that are not transferred because they already exist in the data destination.
210 211 212 213 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 210 class TransferCounters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#found_objects_count ⇒ ::Integer
Returns Objects found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync.
210 211 212 213 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 210 class TransferCounters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#objects_copied_count ⇒ ::Integer
Returns Objects that are copied to the data destination.
210 211 212 213 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 210 class TransferCounters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#objects_failed_count ⇒ ::Integer (readonly)
Returns Output only. Objects that are failed to write to the data destination.
210 211 212 213 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 210 class TransferCounters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#objects_skipped_count ⇒ ::Integer
Returns Objects in the data source that are not transferred because they already exist in the data destination.
210 211 212 213 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 210 class TransferCounters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |