Class: Google::Cloud::Lustre::V1::TransferOperationMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Lustre::V1::TransferOperationMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/lustre/v1/transfer.rb
Overview
Represents the metadata of the long-running transfer operation.
Instance Attribute Summary collapse
-
#counters ⇒ ::Google::Cloud::Lustre::V1::TransferCounters
readonly
Output only.
-
#destination_gcs_path ⇒ ::Google::Cloud::Lustre::V1::GcsPath
readonly
Output only.
-
#destination_lustre_path ⇒ ::Google::Cloud::Lustre::V1::LustrePath
readonly
Output only.
-
#error_summaries ⇒ ::Array<::Google::Cloud::Lustre::V1::ErrorSummary>
readonly
Output only.
-
#source_gcs_path ⇒ ::Google::Cloud::Lustre::V1::GcsPath
readonly
Output only.
-
#source_lustre_path ⇒ ::Google::Cloud::Lustre::V1::LustrePath
readonly
Output only.
-
#transfer_type ⇒ ::Google::Cloud::Lustre::V1::TransferType
readonly
Output only.
Instance Attribute Details
#counters ⇒ ::Google::Cloud::Lustre::V1::TransferCounters (readonly)
Returns Output only. The progress of the transfer operation.
277 278 279 280 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 277 class TransferOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_gcs_path ⇒ ::Google::Cloud::Lustre::V1::GcsPath (readonly)
Returns Output only. Cloud Storage destination.
Note: The following fields are mutually exclusive: destination_gcs_path, destination_lustre_path. If a field in that set is populated, all other fields in the set will automatically be cleared.
277 278 279 280 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 277 class TransferOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_lustre_path ⇒ ::Google::Cloud::Lustre::V1::LustrePath (readonly)
Returns Output only. Lustre destination.
Note: The following fields are mutually exclusive: destination_lustre_path, destination_gcs_path. If a field in that set is populated, all other fields in the set will automatically be cleared.
277 278 279 280 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 277 class TransferOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error_summaries ⇒ ::Array<::Google::Cloud::Lustre::V1::ErrorSummary> (readonly)
Returns Output only. Error summary about the transfer operation.
277 278 279 280 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 277 class TransferOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_gcs_path ⇒ ::Google::Cloud::Lustre::V1::GcsPath (readonly)
Returns Output only. Cloud Storage source.
Note: The following fields are mutually exclusive: source_gcs_path, source_lustre_path. If a field in that set is populated, all other fields in the set will automatically be cleared.
277 278 279 280 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 277 class TransferOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_lustre_path ⇒ ::Google::Cloud::Lustre::V1::LustrePath (readonly)
Returns Output only. Lustre source.
Note: The following fields are mutually exclusive: source_lustre_path, source_gcs_path. If a field in that set is populated, all other fields in the set will automatically be cleared.
277 278 279 280 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 277 class TransferOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transfer_type ⇒ ::Google::Cloud::Lustre::V1::TransferType (readonly)
Returns Output only. The type of transfer occurring.
277 278 279 280 |
# File 'proto_docs/google/cloud/lustre/v1/transfer.rb', line 277 class TransferOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |